/*
 * Copyright (c) 2011, Noel Lemouel
 * All rights reserved.
 */

#include <stdio.h>
#include <ftdi.h>

#include "serial.h"

#define VID 0x0403
#define PID 0x6001

static struct ftdi_context ftdic;

int serial_open(unsigned int baudrate)
{
    int f;
    int interface = INTERFACE_ANY;

	/* init */
	if (ftdi_init(&ftdic) < 0)
	{
		printf("ftdi_init failed\n");
		return -1;
	}

	/* select first interface */
	ftdi_set_interface(&ftdic, interface);

	/* open device */
	f = ftdi_usb_open(&ftdic, VID, PID);
	if (f < 0)
	{
		printf("unable to open ftdi device: %d (%s)\n", f, ftdi_get_error_string(&ftdic));
		return -1;
	}

	/* set baudrate */
	f = ftdi_set_baudrate(&ftdic, baudrate);
	if (f < 0)
	{
		printf("unable to set baudrate: %d (%s)\n", f, ftdi_get_error_string(&ftdic));
		serial_close();
		return -1;
	}

	return 0;
}

int serial_tx(unsigned char* data, int len)
{
	return ftdi_write_data(&ftdic, data, len);
}

int serial_rx(unsigned char* data, int len)
{
	return ftdi_read_data(&ftdic, data, len);
}

int serial_close()
{
    ftdi_usb_close(&ftdic);
    ftdi_deinit(&ftdic);
}

